from setuptools import setup

setup(name='rim_prob_dist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['rim_prob_dist'],
      author='Andres Iglesias',
      author_email='amir_andres@hotmail.com',
      zip_safe=False)
